#
# spec file for package python-smbprotocol
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-smbprotocol
Version:        1.0.1
Release:        bp155.2.9
Summary:        SMBv2/v3 client for Python 2 and 3
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/jborean93/smbprotocol
#Source:         https://files.pythonhosted.org/packages/source/s/smbprotocol/smbprotocol-%%{version}.tar.gz
Source:         https://github.com/jborean93/smbprotocol/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module cryptography >= 2.0}
BuildRequires:  %{python_module ntlm-auth}
BuildRequires:  %{python_module pyasn1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography >= 2.0
Requires:       python-ntlm-auth
Requires:       python-pyasn1
Requires:       python-six
Suggests:       python-gssapi >= 1.4.1
Suggests:       python-ordereddict
BuildArch:      noarch
%python_subpackages

%description
This library implements the SMBv2 and SMBv3 protocol.

Features
--------
-  Negotiation of the SMB 2.0.2 protocol to SMB 3.1.1 (Windows 10/Server
   2016)
-  Authentication with both NTLM and Kerberos
-  Message signing
-  Message encryption (SMB 3.x.x+)
-  Connect to a Tree/Share
-  Opening of files, pipes and directories
-  Set create contexts when opening files
-  Read and writing of files and pipes
-  Sending IOCTL commands
-  Sending of multiple messages in one packet (compounding)

%prep
%setup -q -n smbprotocol-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitelib}/*

%changelog
* Wed Dec 11 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.1
  * Fix issue when reading a large file that exceeds 65KB and
    raises STATUS_END_OF_FILE.
  * Fix issue where listdir, scandir, walk would only enumerate a
    subset of entries in a directories with lots of sub files/
    folders
* Sat Nov 30 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.0
  * Dropped support for Python 2.6 and Python 3.4
  * Added the smbclient package that provides a higher level API
    for interactive with SMB servers
  * Deprecated smbprotocol.query_info in favour of
    smbprotocol.file_info, query_info will be removed in the next
    major release
  * Add automatic symlink resolver when a symlink is in the path
    being opened
  * Fix issue when trying to connect to host with IPv6 address
  * Fix response parsing for SMB2 Create Response Lease V1 and V2
  * Added the ability to set the Oplock level when opening a file
  * Revamped the socket listener and message processor to run in a
    separate thread for faster message resolving
  * Added the FileSystemWatcher in change_notify.py to provider a
    way to watch for changes on the SMB filesystem
  * Added the .cancel() method onto a Request to cancel an SMB
    request on the server
* Thu Sep 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.2.0
  * Fix issue where timeout was not being applied to the new
    connection
  * Fix various deprecated regex escape patterns
  * Simplified the fallback NTLM context object
* Thu Jan  3 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Sat Dec 29 2018 mardnh@gmx.de
- Update to version 0.1.1
  * Fix initial negotiate message not setting connection timeout
    value.
  * Fix endless loop when running a compound message that failed.
* Thu Sep  6 2018 mardnh@gmx.de
- Initial package, version 0.1.0
